Unreleased changes
------------------

* Changed plot_history default line width and marker size.
* Bugfix for swap_columns sample_modifier in orca_handler_util
* Fixed filter_tf_garbage option. The tf CPP_MIN_LOG_LEVEl variable should now be set when instantiating the Organizer.
* Added epoch/fileno to orcapred.
* Added possibility to define inference files.
* Pred and inference will now automatically look for the best model to load.
* Various fixes


Version 0
---------

0.5 / 2019-05-14
~~~~~~~~~~~~~~~~~~~
* Various fixes and small additions
* model are automatically dumped as json
* support for csv learning rate files

0.4.1 / 2019-04-17
~~~~~~~~~~~~~~~~~~~
* Release of v0.4.1
